@@ -59,15 +59,17 @@ struct _TasklistPlugin
 
 
 
-static void     tasklist_plugin_construct           (XfcePanelPlugin *panel_plugin);
-static void     tasklist_plugin_orientation_changed (XfcePanelPlugin *panel_plugin,
-                                                     GtkOrientation   orientation);
-static gboolean tasklist_plugin_size_changed        (XfcePanelPlugin *panel_plugin,
-                                                     gint             size);
-static void     tasklist_plugin_configure_plugin    (XfcePanelPlugin *panel_plugin);
-static gboolean tasklist_plugin_handle_expose_event (GtkWidget       *widget,
-                                                     GdkEventExpose  *event,
-                                                     TasklistPlugin  *plugin);
+static void     tasklist_plugin_construct               (XfcePanelPlugin    *panel_plugin);
+static void     tasklist_plugin_orientation_changed     (XfcePanelPlugin    *panel_plugin,
+                                                         GtkOrientation      orientation);
+static gboolean tasklist_plugin_size_changed            (XfcePanelPlugin    *panel_plugin,
+                                                         gint                size);
+static void     tasklist_plugin_screen_position_changed (XfcePanelPlugin    *panel_plugin,
+                                                         XfceScreenPosition  position);
+static void     tasklist_plugin_configure_plugin        (XfcePanelPlugin    *panel_plugin);
+static gboolean tasklist_plugin_handle_expose_event     (GtkWidget          *widget,
+                                                         GdkEventExpose     *event,
+                                                         TasklistPlugin     *plugin);
 
 
 
@@ -85,6 +87,7 @@ tasklist_plugin_class_init (TasklistPluginClass *klass)
   plugin_class->construct = tasklist_plugin_construct;
   plugin_class->orientation_changed = tasklist_plugin_orientation_changed;
   plugin_class->size_changed = tasklist_plugin_size_changed;
+  plugin_class->screen_position_changed = tasklist_plugin_screen_position_changed;
   plugin_class->configure_plugin = tasklist_plugin_configure_plugin;
 }
 
@@ -180,6 +183,19 @@ tasklist_plugin_size_changed (XfcePanelPlugin *panel_plugin,
 
 
 
+static void
+tasklist_plugin_screen_position_changed (XfcePanelPlugin    *panel_plugin,
+                                         XfceScreenPosition  position)
+{
+  TasklistPlugin *plugin = XFCE_TASKLIST_PLUGIN (panel_plugin);
+
+  /* update monitor geometry; this function is also triggered when
+   * the panel is moved to another monitor during runtime */
+  xfce_tasklist_update_monitor_geometry (XFCE_TASKLIST (plugin->tasklist));
+}
+
+
+
 static void
 tasklist_plugin_configure_plugin (XfcePanelPlugin *panel_plugin)
 {
